# coding: utf-8

"""
    PSI Notifier

     Module containing a class for interacting with the PSI Notification infrastructure   # noqa: E501
"""

from setuptools import setup, find_packages  # noqa: H301

NAME="psi_notifier"
VERSION='0.2.0'
REQUIRES=['boto3']

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

setup(
    name=NAME,
    version=VERSION,
    description="PSI Notification handler",
    author="Pearson Service Insights",
    author_email="jonathan.morris@pearson.com",
    url="https://gitlab.com/pearson-io-swa/integrations",
    keywords=["Pearson", "PSI", "SNS", "Alert", "Notification"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
      Module containing a class for interacting with the PSI Notification infrastructure and exception hook to notify on any uncaught exception.   # noqa: E501
    """
)
